#!/usr/bin/env node
"use strict";

var _colors = _interopRequireDefault(require("colors"));

var _inquirer = require("inquirer");

var _yargonaut = _interopRequireDefault(require("yargonaut"));

var _yargs = _interopRequireDefault(require("yargs"));

var _package = _interopRequireDefault(require("../package.json"));

var _monitor = _interopRequireDefault(require("./monitor.js"));

var _send = _interopRequireDefault(require("./send.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint prefer-template: 0 */
_yargonaut.default.style('blue');

const Task = {
  MONITOR: 'MONITOR',
  SEND: 'SEND'
};

async function runInteractive() {
  const {
    task,
    port,
    address
  } = await (0, _inquirer.prompt)([{
    type: 'list',
    name: 'task',
    message: 'What do you want to do?',
    choices: [{
      value: Task.MONITOR,
      name: 'Monitor OSC messages'
    }, {
      value: Task.SEND,
      name: 'Send OSC messages'
    }]
  }, {
    type: 'input',
    name: 'port',
    message: 'What port do you want to connect to?',
    default: 666,
    filter: value => parseInt(value)
  }, {
    type: 'input',
    name: 'address',
    message: 'What host IP do you want to connect to?',
    default: '0.0.0.0'
  }]);

  if (task === Task.MONITOR) {
    await (0, _monitor.default)({
      port,
      address
    });
  } else if (task === Task.SEND) {
    await (0, _send.default)({
      port,
      address
    });
  } else {
    throw new TypeError(`Unknown task: ${task}`);
  }
} // Setup CLI


_yargs.default.usage(`OSC Debugger\n\n`.yellow.bold + `A simple but charming OSC debugging tool for the terminal. Runs in interactive mode if no command is specified.`).command('monitor [options...]', 'Monitor OSC messages', {
  port: {
    alias: 'p',
    default: '8888',
    demandOption: true,
    describe: 'The port you want to listen to'
  }
}, async ({
  port
}) => {
  await (0, _monitor.default)({
    port
  });
}).command('send [options...]', 'Send OSC messages', {
  address: {
    alias: 'a',
    default: '0.0.0.0',
    describe: 'The IP address you want to send to'
  },
  port: {
    alias: 'p',
    default: '8888',
    demandOption: true,
    describe: 'The port you want to send to'
  }
}, ({
  port,
  address
}) => {
  (0, _send.default)({
    port,
    address
  });
}).command('$0', false, () => {}, () => {
  runInteractive().catch(err => {
    console.log('An error occured:');
    console.log(err);
    console.log(err.stack);
  });
}).version(_package.default.version).help().alias('h', 'help').parse();